@@ -219,11 +219,12 @@ class Network(LibraryComponent):
 
         ``timeout`` Timeout in milliseconds. Uses default timeout of 10 seconds if not set.
 
-        ``wait_until`` <"load"|"domcontentloaded"|"networkidle"> When to consider operation succeeded, defaults to load.
-        Events can be either:
+        ``wait_until`` <"load"|"domcontentloaded"|"networkidle|"commit""> When to consider operation succeeded,
+        defaults to load. Events can be either:
         'domcontentloaded' - consider operation to be finished when the DOMContentLoaded event is fired.
         'load' - consider operation to be finished when the load event is fired.
         'networkidle' - consider operation to be finished when there are no network connections for at least 500 ms.
+        `commit` - consider operation to be finished when network response is received and the document started loading.
 
         Keyword works only when page is loaded and does not work if URL fragment changes. Example if
         https://marketsquare.github.io/robotframework-browser/Browser.html changes to
