@@ -75,8 +75,8 @@ class Promises(LibraryComponent):
         for arg in args:
             parts = arg.partition("=")
             if parts[0].strip() in keyword_arguments:
-                if parts[2].strip() in DialogAction.__members__:
-                    named[parts[0].strip()] = DialogAction[parts[2].strip()]
+                if parts[2].strip().lower() in DialogAction.__members__:
+                    named[parts[0].strip()] = DialogAction[parts[2].strip().lower()]
                 else:
                     named[parts[0].strip()] = parts[2].strip()
             else:
@@ -181,9 +181,7 @@ class Promises(LibraryComponent):
 
     @keyword(tags=("Setter", "PageContent"))
     def promise_to_upload_file(self, path: PathLike):
-        """*!!DEPRECATED!!* Use keyword `Upload File By Selector` instead if possible. If your use case _needs_ promise to upload file please let the Browser team know by creating an issue.
-
-        Returns a promise that resolves when file from ``path`` has been uploaded.
+        """Returns a promise that resolves when file from ``path`` has been uploaded.
 
         Fails if the upload has not happened during timeout.
 
@@ -191,13 +189,13 @@ class Promises(LibraryComponent):
 
         ``path`` Path to file to be uploaded.
 
-        !! Due to a certain problem with Playwright library currently files over 74 MB will fail to upload. !!
-
         Example use:
 
-        | ${promise}=    `Promise To Upload File`    ${CURDIR}/test_upload_file
-        | `Click`          \\#file_chooser
-        | ${upload_result}=  `Wait For`  ${promise}
+        | ${promise}=    `Promise To Upload File`    ${CURDIR}/test_upload_file.txt
+        | `Click`          id=open_file_chooser_button
+        | ${upload_result}=    `Wait For`    ${promise}
+
+        Alternatively, you can use `Upload File By Selector` keyword.
         """
         promise = self._executor.submit(self._upload_file, **{"path": path})
         self.unresolved_promises.add(promise)
